#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: openttd
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2010-12-11
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="openttd"
VERSION="1.0.5"
OPENSFX_VER="0.2.3"
OPENGFX_VER="0.3.1"
OPENMSX_VER="0.3.1"
ARCH="i686"
CPU="i686"
BUILD="66.1"
EXT="txz"
HOMEPAGE="http://www.openttd.org"
SRCLNK="http://binaries.openttd.org/releases/$VERSION/$NAME-$VERSION-source.tar.bz2 \
		http://de.binaries.openttd.org/binaries/bananas/basesound/OpenSFX-$OPENSFX_VER.tar.gz \
		http://de.binaries.openttd.org/binaries/bananas/basegraphic/OpenGFX-$OPENGFX_VER.tar.gz \
		http://de.binaries.openttd.org/binaries/bananas/basemusic/OpenMSX-$OPENMSX_VER.tar.gz"
DESCRIPTION="Open clone of the game Trasport Tycoon Deluxe"
DOCS="COPYING changelog.txt readme.txt known-bugs.txt docs/Manual.txt docs/multiplayer.txt docs/HOWTO* docs/32bpp.txt docs/obg_format.txt"
ADDSRC="ttd-grf.tar.gz ttd-gm.tar.gz"
INCSRC=""
ADDDEP="TiMidity++,jack"
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

# Compiling and installing
./configure \
	--prefix-dir=/usr \
	--man-dir=man/man6 --doc-dir=doc/$NAME-$VERSION \
 	--binary-dir=share/openttd \
 	--data-dir=share/openttd \
 	--icon-dir=share/openttd \
 	--personal-dir=.openttd \
 	--install-dir=$PKGDIR \
 	--with-zlib \
 	--with-png \
 	--with-sdl \
 	--with-freetype \
 	--with-fontconfig \
 	--with-midi=timidity \
|| exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

# Exec
install -dv $PKGDIR/usr/bin
cat > $PKGDIR/usr/bin/$NAME << EOF
cd /usr/share/$NAME
./$NAME
EOF
chmod a+x $PKGDIR/usr/bin/$NAME

# Including original game data
tar xfv $CWD/ttd-gm.tar.gz -C $PKGDIR/usr/share/$NAME/gm --strip-components=1 || exit 1
tar xfv $CWD/ttd-grf.tar.gz -C $PKGDIR/usr/share/$NAME/data --strip-components=1 || exit 1

# Including open game data
cp $CWD/OpenGFX-$OPENGFX_VER.tar.gz $PKGDIR/usr/share/$NAME/data && gunzip $PKGDIR/usr/share/$NAME/data/OpenGFX-$OPENGFX_VER.tar.gz || exit 1
cp $CWD/OpenSFX-$OPENSFX_VER.tar.gz $PKGDIR/usr/share/$NAME/data && gunzip $PKGDIR/usr/share/$NAME/data/OpenSFX-$OPENSFX_VER.tar.gz || exit 1
tar xfv $CWD/OpenMSX-$OPENMSX_VER.tar.gz -C $PKGDIR/usr/share/$NAME/gm  # && tar xfv $PKGDIR/usr/share/$NAME/gm/OpenMSX-$OPENMSX_VER.tar.gz   || exit 1

# Icon

# Desktop entry

# Docs, man, info
install -dv $PKGDIR/usr/doc/$NAME-$VERSION

# Unnedeed stuff
rm -fr $PKGDIR/usr/share/openttd/docs
rm -fr $PKGDIR/usr/share/doc
rm -fr $PKGDIR/usr/share/man
rm -fr $PKGDIR/usr/share/$NAME/openttd.32.xpm

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: OpenTTD is a clone of the famous game "Transport Tycoon Deluxe",
$NAME: originally written by Chris Sawyer. It attempts to mimic the original
$NAME: as closely as possible, while extending it with new features.
$NAME: The package contains the new open replacement for graphics and sounds
$NAME: Data files from the original game (which is considered abandonware)
$NAME: are still included in the package. Although free as in beer, 
$NAME: abandonware has a legal status that is still questionable.
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z -c $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for s in $SRCLNK
	do echo $s >> $PKG.src
done
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
DEL_SRCDIR=${DEL_SRCDIR-1}
if [ "$DEL_SRCDIR" -eq "1" ]; then
	rm -rf $SRCDIR
	rm -rf $PKGDIR
fi

### Done. Ciao!
